Learn R Programming

smoke (version 2.0.1)

ligand: Getter for "Bli" slot of ligand concentration

Description

The getter function for "Bli" slot of ligand concentration. If the slot is empty, there will be an error message: "please input ligand concentration".

Usage

ligand(obj)

Value

a numeric vector for the ligand concentration in BLI experiment

Arguments

obj

obj of "Bli" class

Author

tools:::Rd_package_author("smoke")

Maintainer: tools:::Rd_package_maintainer("smoke")

See Also

ligand<-

Examples

Run this code
conc <- ligand(bli)

Run the code above in your browser using DataLab