powered by
The getter function for "Bli" slot of ligand concentration. If the slot is empty, there will be an error message: "please input ligand concentration".
ligand(obj)
a numeric vector for the ligand concentration in BLI experiment
obj of "Bli" class
obj
tools:::Rd_package_author("smoke")
Maintainer: tools:::Rd_package_maintainer("smoke")
ligand<-
conc <- ligand(bli)
Run the code above in your browser using DataLab